@@ -86,7 +86,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56300
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56100
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56300
 #  endif
 #endif
 
@@ -139,6 +139,12 @@
 #else
 #  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text)
 #endif
+
+#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x56200
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_98(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_98(text)
+#endif
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -204,7 +210,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56100
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56300
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -214,7 +220,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56100
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56300
 #  endif
 #endif
 
@@ -257,6 +263,12 @@
 #else
 #  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text)
 #endif
+
+#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x56200
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_98(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_98(text)
+#endif
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
